# Release 0.8.39

!!!tip inline end "Need Help?"
    The SuperCowPowers team is happy to give any assistance needed when setting up AWS and Workbench. So please contact us at [workbench@supercowpowers.com](mailto:workbench@supercowpowers.com) or on chat us up on [Discord](https://discord.gg/WHAJuz8sw8) 

The Workbench framework continues to flex to support different real world use cases when operating a set of production machine learning pipelines.

**Note:** These release notes cover the changes from `0.8.36` to `0.8.39`


### General
Just a small set of error handling and bug fixes.

### API Changes
None
	
### Improvements/Fixes
**Scatter Plot:**
Fixed a corner case where the hoover columns included AWS generated fields.

**Athena Queries:**
Put in additional error handling and retries when looking for and querying Athena/Glue Catalogs. These changes affect both DataSource and Features (which have DataSources internally for offline storage).

**FeatureSet Creation:**
Put in additional error handling and retries when pulling AWS meta data for FeatureSets (and internal DataSources).

## Specific Code Changes
 
<a href="https://github.com/supercowpowers/workbench/compare/v0.8.36...v0.8.39" target="_blank">Code Diff v0.8.36 --> v0.8.39</a> 

Who doesn't like looking at code! Also +3 points for getting down this far! Here's a cow joke as a reward:

> ***That feeling like you’ve done this before?
      .... Deja-moo***

## Questions?
<img align="right" src="../../../images/scp.png" width="180">

The SuperCowPowers team is happy to answer any questions you may have about AWS and Workbench. Please contact us at [workbench@supercowpowers.com](mailto:workbench@supercowpowers.com) or on chat us up on [Discord](https://discord.gg/WHAJuz8sw8) 


